/// <reference path="./custom.d.ts" />
// tslint:disable
/**
 * Climatology - A Weather Source API
 * Daily and hourly climatological weather data for latitude/longitude points, ZIP/Postal Codes, Designated Market Areas, and OnPoint™ points. The Weather Source Climatology API is built upon the [OnPoint™ Platform](https://weathersource.com/products/onpoint-platform/) which ensures data that is gap-free, homogeneous, and ready for immediate analysis. We offer the highest resolution grid on the market, covering every landmass in the world and up to 200 miles offshore.    **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
 *
 * OpenAPI spec version: 2.0.0
 * Contact: support@weathersource.com
 *
 * NOTE: This file is auto generated by the swagger code generator program.
 * https://github.com/swagger-api/swagger-codegen.git
 * Do not edit the file manually.
 */

import * as url from "url";
import * as isomorphicFetch from "isomorphic-fetch";
import { Configuration } from "./configuration";

const BASE_PATH = "https://climatology.weathersourceapis.com/v2".replace(/\/+$/, "");

/**
 *
 * @export
 */
export const COLLECTION_FORMATS = {
    csv: ",",
    ssv: " ",
    tsv: "\t",
    pipes: "|",
};

/**
 *
 * @export
 * @interface FetchAPI
 */
export interface FetchAPI {
    (url: string, init?: any): Promise<Response>;
}

/**
 *
 * @export
 * @interface FetchArgs
 */
export interface FetchArgs {
    url: string;
    options: any;
}

/**
 *
 * @export
 * @class BaseAPI
 */
export class BaseAPI {
    protected configuration: Configuration;

    constructor(configuration?: Configuration, protected basePath: string = BASE_PATH, protected fetch: FetchAPI = isomorphicFetch) {
        if (configuration) {
            this.configuration = configuration;
            this.basePath = configuration.basePath || this.basePath;
        }
    }
};

/**
 *
 * @export
 * @class RequiredError
 * @extends {Error}
 */
export class RequiredError extends Error {
    name: "RequiredError"
    constructor(public field: string, msg?: string) {
        super(msg);
    }
}

/**
 * A list of OnPoint™ points related to the location
 * @export
 */
export type BoundingPoints = Array<BoundingPointsInner>
/**
 * 
 * @export
 * @interface BoundingPointsInner
 */
export interface BoundingPointsInner {
    /**
     * 
     * @type {OnpointId}
     * @memberof BoundingPointsInner
     */
    onpointId: OnpointId;
    /**
     * 
     * @type {Latitude}
     * @memberof BoundingPointsInner
     */
    latitude: Latitude;
    /**
     * 
     * @type {Longitude}
     * @memberof BoundingPointsInner
     */
    longitude: Longitude;
    /**
     * 
     * @type {Grid}
     * @memberof BoundingPointsInner
     */
    grid: Grid;
    /**
     * 
     * @type {Distance}
     * @memberof BoundingPointsInner
     */
    distance: Distance;
    /**
     * 
     * @type {Elevation}
     * @memberof BoundingPointsInner
     */
    elevation: Elevation;
}
/**
 * Cloud Cover as a percent value.
 * @export
 */
export type CldCvr = number
/**
 * Average Cloud Cover as a percent value.
 * @export
 */
export type CldCvrAvg = number
/**
 * The Standard Deviation of Average Cloud Cover as a percent value.
 * @export
 */
export type CldCvrAvgSd = number
/**
 * Maximum Cloud Cover as a percent value.
 * @export
 */
export type CldCvrMax = number
/**
 * The Standard Deviation of Maximum Cloud Cover as a percent value.
 * @export
 */
export type CldCvrMaxSd = number
/**
 * Minimum Cloud Cover as a percent value.
 * @export
 */
export type CldCvrMin = number
/**
 * The Standard Deviation of Minimum Cloud Cover as a percent value.
 * @export
 */
export type CldCvrMinSd = number
/**
 * The Standard Deviation of Cloud Cover as a percent value.
 * @export
 */
export type CldCvrSd = number
/**
 * An array of daily weather climatology objects.
 * @export
 */
export type ClimatologyDayArr = Array<ClimatologyDayObj>
/**
 * A daily weather climatology object.
 * @export
 * @interface ClimatologyDayObj
 */
export interface ClimatologyDayObj {
    /**
     * 
     * @type {string}
     * @memberof ClimatologyDayObj
     */
    date: string;
    /**
     * 
     * @type {CldCvrMin}
     * @memberof ClimatologyDayObj
     */
    cldCvrMin?: CldCvrMin;
    /**
     * 
     * @type {CldCvrMinSd}
     * @memberof ClimatologyDayObj
     */
    cldCvrMinSd?: CldCvrMinSd;
    /**
     * 
     * @type {CldCvrAvg}
     * @memberof ClimatologyDayObj
     */
    cldCvrAvg?: CldCvrAvg;
    /**
     * 
     * @type {CldCvrAvgSd}
     * @memberof ClimatologyDayObj
     */
    cldCvrAvgSd?: CldCvrAvgSd;
    /**
     * 
     * @type {CldCvrMax}
     * @memberof ClimatologyDayObj
     */
    cldCvrMax?: CldCvrMax;
    /**
     * 
     * @type {CldCvrMaxSd}
     * @memberof ClimatologyDayObj
     */
    cldCvrMaxSd?: CldCvrMaxSd;
    /**
     * 
     * @type {DewPtMin}
     * @memberof ClimatologyDayObj
     */
    dewPtMin?: DewPtMin;
    /**
     * 
     * @type {DewPtMinSd}
     * @memberof ClimatologyDayObj
     */
    dewPtMinSd?: DewPtMinSd;
    /**
     * 
     * @type {DewPtAvg}
     * @memberof ClimatologyDayObj
     */
    dewPtAvg?: DewPtAvg;
    /**
     * 
     * @type {DewPtAvgSd}
     * @memberof ClimatologyDayObj
     */
    dewPtAvgSd?: DewPtAvgSd;
    /**
     * 
     * @type {DewPtMax}
     * @memberof ClimatologyDayObj
     */
    dewPtMax?: DewPtMax;
    /**
     * 
     * @type {DewPtMaxSd}
     * @memberof ClimatologyDayObj
     */
    dewPtMaxSd?: DewPtMaxSd;
    /**
     * 
     * @type {FeelsLikeMin}
     * @memberof ClimatologyDayObj
     */
    feelsLikeMin?: FeelsLikeMin;
    /**
     * 
     * @type {FeelsLikeMinSd}
     * @memberof ClimatologyDayObj
     */
    feelsLikeMinSd?: FeelsLikeMinSd;
    /**
     * 
     * @type {FeelsLikeAvg}
     * @memberof ClimatologyDayObj
     */
    feelsLikeAvg?: FeelsLikeAvg;
    /**
     * 
     * @type {FeelsLikeAvgSd}
     * @memberof ClimatologyDayObj
     */
    feelsLikeAvgSd?: FeelsLikeAvgSd;
    /**
     * 
     * @type {FeelsLikeMax}
     * @memberof ClimatologyDayObj
     */
    feelsLikeMax?: FeelsLikeMax;
    /**
     * 
     * @type {FeelsLikeMaxSd}
     * @memberof ClimatologyDayObj
     */
    feelsLikeMaxSd?: FeelsLikeMaxSd;
    /**
     * 
     * @type {MslPresMin}
     * @memberof ClimatologyDayObj
     */
    mslPresMin?: MslPresMin;
    /**
     * 
     * @type {MslPresMinSd}
     * @memberof ClimatologyDayObj
     */
    mslPresMinSd?: MslPresMinSd;
    /**
     * 
     * @type {MslPresAvg}
     * @memberof ClimatologyDayObj
     */
    mslPresAvg?: MslPresAvg;
    /**
     * 
     * @type {MslPresAvgSd}
     * @memberof ClimatologyDayObj
     */
    mslPresAvgSd?: MslPresAvgSd;
    /**
     * 
     * @type {MslPresMax}
     * @memberof ClimatologyDayObj
     */
    mslPresMax?: MslPresMax;
    /**
     * 
     * @type {MslPresMaxSd}
     * @memberof ClimatologyDayObj
     */
    mslPresMaxSd?: MslPresMaxSd;
    /**
     * 
     * @type {Precip}
     * @memberof ClimatologyDayObj
     */
    precip?: Precip;
    /**
     * 
     * @type {PrecipSd}
     * @memberof ClimatologyDayObj
     */
    precipSd?: PrecipSd;
    /**
     * 
     * @type {PrecipFreq}
     * @memberof ClimatologyDayObj
     */
    precipFreq?: PrecipFreq;
    /**
     * 
     * @type {PrecipFreq0}
     * @memberof ClimatologyDayObj
     */
    precipFreq0?: PrecipFreq0;
    /**
     * 
     * @type {PrecipFreq001To009}
     * @memberof ClimatologyDayObj
     */
    precipFreq001To009?: PrecipFreq001To009;
    /**
     * 
     * @type {PrecipFreq010To024}
     * @memberof ClimatologyDayObj
     */
    precipFreq010To024?: PrecipFreq010To024;
    /**
     * 
     * @type {PrecipFreq025To049}
     * @memberof ClimatologyDayObj
     */
    precipFreq025To049?: PrecipFreq025To049;
    /**
     * 
     * @type {PrecipFreq050To099}
     * @memberof ClimatologyDayObj
     */
    precipFreq050To099?: PrecipFreq050To099;
    /**
     * 
     * @type {PrecipFreq100To249}
     * @memberof ClimatologyDayObj
     */
    precipFreq100To249?: PrecipFreq100To249;
    /**
     * 
     * @type {PrecipFreq250To499}
     * @memberof ClimatologyDayObj
     */
    precipFreq250To499?: PrecipFreq250To499;
    /**
     * 
     * @type {PrecipFreq500Plus}
     * @memberof ClimatologyDayObj
     */
    precipFreq500Plus?: PrecipFreq500Plus;
    /**
     * 
     * @type {RadSolarMin}
     * @memberof ClimatologyDayObj
     */
    radSolarMin?: RadSolarMin;
    /**
     * 
     * @type {RadSolarMinSd}
     * @memberof ClimatologyDayObj
     */
    radSolarMinSd?: RadSolarMinSd;
    /**
     * 
     * @type {RadSolarAvg}
     * @memberof ClimatologyDayObj
     */
    radSolarAvg?: RadSolarAvg;
    /**
     * 
     * @type {RadSolarAvgSd}
     * @memberof ClimatologyDayObj
     */
    radSolarAvgSd?: RadSolarAvgSd;
    /**
     * 
     * @type {RadSolarMax}
     * @memberof ClimatologyDayObj
     */
    radSolarMax?: RadSolarMax;
    /**
     * 
     * @type {RadSolarMaxSd}
     * @memberof ClimatologyDayObj
     */
    radSolarMaxSd?: RadSolarMaxSd;
    /**
     * 
     * @type {RadSolarTot}
     * @memberof ClimatologyDayObj
     */
    radSolarTot?: RadSolarTot;
    /**
     * 
     * @type {RadSolarTotSd}
     * @memberof ClimatologyDayObj
     */
    radSolarTotSd?: RadSolarTotSd;
    /**
     * 
     * @type {RelHumMin}
     * @memberof ClimatologyDayObj
     */
    relHumMin?: RelHumMin;
    /**
     * 
     * @type {RelHumMinSd}
     * @memberof ClimatologyDayObj
     */
    relHumMinSd?: RelHumMinSd;
    /**
     * 
     * @type {RelHumAvg}
     * @memberof ClimatologyDayObj
     */
    relHumAvg?: RelHumAvg;
    /**
     * 
     * @type {RelHumAvgSd}
     * @memberof ClimatologyDayObj
     */
    relHumAvgSd?: RelHumAvgSd;
    /**
     * 
     * @type {RelHumMax}
     * @memberof ClimatologyDayObj
     */
    relHumMax?: RelHumMax;
    /**
     * 
     * @type {RelHumMaxSd}
     * @memberof ClimatologyDayObj
     */
    relHumMaxSd?: RelHumMaxSd;
    /**
     * 
     * @type {SfcPresMin}
     * @memberof ClimatologyDayObj
     */
    sfcPresMin?: SfcPresMin;
    /**
     * 
     * @type {SfcPresMinSd}
     * @memberof ClimatologyDayObj
     */
    sfcPresMinSd?: SfcPresMinSd;
    /**
     * 
     * @type {SfcPresAvg}
     * @memberof ClimatologyDayObj
     */
    sfcPresAvg?: SfcPresAvg;
    /**
     * 
     * @type {SfcPresAvgSd}
     * @memberof ClimatologyDayObj
     */
    sfcPresAvgSd?: SfcPresAvgSd;
    /**
     * 
     * @type {SfcPresMax}
     * @memberof ClimatologyDayObj
     */
    sfcPresMax?: SfcPresMax;
    /**
     * 
     * @type {SfcPresMaxSd}
     * @memberof ClimatologyDayObj
     */
    sfcPresMaxSd?: SfcPresMaxSd;
    /**
     * 
     * @type {SnowDepth}
     * @memberof ClimatologyDayObj
     */
    snowDepth?: SnowDepth;
    /**
     * 
     * @type {SnowDepthSd}
     * @memberof ClimatologyDayObj
     */
    snowDepthSd?: SnowDepthSd;
    /**
     * 
     * @type {Snowfall}
     * @memberof ClimatologyDayObj
     */
    snowfall?: Snowfall;
    /**
     * 
     * @type {SnowfallSd}
     * @memberof ClimatologyDayObj
     */
    snowfallSd?: SnowfallSd;
    /**
     * 
     * @type {SnowfallFreq}
     * @memberof ClimatologyDayObj
     */
    snowfallFreq?: SnowfallFreq;
    /**
     * 
     * @type {SnowfallFreq0}
     * @memberof ClimatologyDayObj
     */
    snowfallFreq0?: SnowfallFreq0;
    /**
     * 
     * @type {SnowfallFreq001To009}
     * @memberof ClimatologyDayObj
     */
    snowfallFreq001To009?: SnowfallFreq001To009;
    /**
     * 
     * @type {SnowfallFreq010To024}
     * @memberof ClimatologyDayObj
     */
    snowfallFreq010To024?: SnowfallFreq010To024;
    /**
     * 
     * @type {SnowfallFreq025To049}
     * @memberof ClimatologyDayObj
     */
    snowfallFreq025To049?: SnowfallFreq025To049;
    /**
     * 
     * @type {SnowfallFreq050To099}
     * @memberof ClimatologyDayObj
     */
    snowfallFreq050To099?: SnowfallFreq050To099;
    /**
     * 
     * @type {SnowfallFreq100To149}
     * @memberof ClimatologyDayObj
     */
    snowfallFreq100To149?: SnowfallFreq100To149;
    /**
     * 
     * @type {SnowfallFreq150To249}
     * @memberof ClimatologyDayObj
     */
    snowfallFreq150To249?: SnowfallFreq150To249;
    /**
     * 
     * @type {SnowfallFreq250Plus}
     * @memberof ClimatologyDayObj
     */
    snowfallFreq250Plus?: SnowfallFreq250Plus;
    /**
     * 
     * @type {SpcHumMin}
     * @memberof ClimatologyDayObj
     */
    spcHumMin?: SpcHumMin;
    /**
     * 
     * @type {SpcHumMinSd}
     * @memberof ClimatologyDayObj
     */
    spcHumMinSd?: SpcHumMinSd;
    /**
     * 
     * @type {SpcHumAvg}
     * @memberof ClimatologyDayObj
     */
    spcHumAvg?: SpcHumAvg;
    /**
     * 
     * @type {SpcHumAvgSd}
     * @memberof ClimatologyDayObj
     */
    spcHumAvgSd?: SpcHumAvgSd;
    /**
     * 
     * @type {SpcHumMax}
     * @memberof ClimatologyDayObj
     */
    spcHumMax?: SpcHumMax;
    /**
     * 
     * @type {SpcHumMaxSd}
     * @memberof ClimatologyDayObj
     */
    spcHumMaxSd?: SpcHumMaxSd;
    /**
     * 
     * @type {TempMin}
     * @memberof ClimatologyDayObj
     */
    tempMin?: TempMin;
    /**
     * 
     * @type {TempMinSd}
     * @memberof ClimatologyDayObj
     */
    tempMinSd?: TempMinSd;
    /**
     * 
     * @type {TempAvg}
     * @memberof ClimatologyDayObj
     */
    tempAvg?: TempAvg;
    /**
     * 
     * @type {TempAvgSd}
     * @memberof ClimatologyDayObj
     */
    tempAvgSd?: TempAvgSd;
    /**
     * 
     * @type {TempMax}
     * @memberof ClimatologyDayObj
     */
    tempMax?: TempMax;
    /**
     * 
     * @type {TempMaxSd}
     * @memberof ClimatologyDayObj
     */
    tempMaxSd?: TempMaxSd;
    /**
     * 
     * @type {WetBulbMin}
     * @memberof ClimatologyDayObj
     */
    wetBulbMin?: WetBulbMin;
    /**
     * 
     * @type {WetBulbMinSd}
     * @memberof ClimatologyDayObj
     */
    wetBulbMinSd?: WetBulbMinSd;
    /**
     * 
     * @type {WetBulbAvg}
     * @memberof ClimatologyDayObj
     */
    wetBulbAvg?: WetBulbAvg;
    /**
     * 
     * @type {WetBulbAvgSd}
     * @memberof ClimatologyDayObj
     */
    wetBulbAvgSd?: WetBulbAvgSd;
    /**
     * 
     * @type {WetBulbMax}
     * @memberof ClimatologyDayObj
     */
    wetBulbMax?: WetBulbMax;
    /**
     * 
     * @type {WetBulbMaxSd}
     * @memberof ClimatologyDayObj
     */
    wetBulbMaxSd?: WetBulbMaxSd;
    /**
     * 
     * @type {WindDirAvg}
     * @memberof ClimatologyDayObj
     */
    windDirAvg?: WindDirAvg;
    /**
     * 
     * @type {WindDir80mAvg}
     * @memberof ClimatologyDayObj
     */
    windDir80mAvg?: WindDir80mAvg;
    /**
     * 
     * @type {WindDir100mAvg}
     * @memberof ClimatologyDayObj
     */
    windDir100mAvg?: WindDir100mAvg;
    /**
     * 
     * @type {WindSpdMin}
     * @memberof ClimatologyDayObj
     */
    windSpdMin?: WindSpdMin;
    /**
     * 
     * @type {WindSpdMinSd}
     * @memberof ClimatologyDayObj
     */
    windSpdMinSd?: WindSpdMinSd;
    /**
     * 
     * @type {WindSpdAvg}
     * @memberof ClimatologyDayObj
     */
    windSpdAvg?: WindSpdAvg;
    /**
     * 
     * @type {WindSpdAvgSd}
     * @memberof ClimatologyDayObj
     */
    windSpdAvgSd?: WindSpdAvgSd;
    /**
     * 
     * @type {WindSpdMax}
     * @memberof ClimatologyDayObj
     */
    windSpdMax?: WindSpdMax;
    /**
     * 
     * @type {WindSpdMaxSd}
     * @memberof ClimatologyDayObj
     */
    windSpdMaxSd?: WindSpdMaxSd;
}
/**
 * Daily Designated Market Area climatological weather object
 * @export
 * @interface ClimatologyDmaDayObj
 */
export interface ClimatologyDmaDayObj {
    /**
     * 
     * @type {DmaObj}
     * @memberof ClimatologyDmaDayObj
     */
    location: DmaObj;
    /**
     * 
     * @type {DateRangeObj}
     * @memberof ClimatologyDmaDayObj
     */
    dateRange: DateRangeObj;
    /**
     * 
     * @type {FieldListDayObj}
     * @memberof ClimatologyDmaDayObj
     */
    fieldList: FieldListDayObj;
    /**
     * 
     * @type {ClimatologyDayArr}
     * @memberof ClimatologyDmaDayObj
     */
    climatology: ClimatologyDayArr;
}
/**
 * Hourly Designated Market Area climatological weather object
 * @export
 * @interface ClimatologyDmaHourObj
 */
export interface ClimatologyDmaHourObj {
    /**
     * 
     * @type {DmaObj}
     * @memberof ClimatologyDmaHourObj
     */
    location: DmaObj;
    /**
     * 
     * @type {TimestampRangeObj}
     * @memberof ClimatologyDmaHourObj
     */
    timestampRange: TimestampRangeObj;
    /**
     * 
     * @type {FieldListHourObj}
     * @memberof ClimatologyDmaHourObj
     */
    fieldList: FieldListHourObj;
    /**
     * 
     * @type {ClimatologyHourArr}
     * @memberof ClimatologyDmaHourObj
     */
    climatology: ClimatologyHourArr;
}
/**
 * An array of hourly weather climatology objects.
 * @export
 */
export type ClimatologyHourArr = Array<ClimatologyHourObj>
/**
 * An hourly weather climatology object.
 * @export
 * @interface ClimatologyHourObj
 */
export interface ClimatologyHourObj {
    /**
     * 
     * @type {Timestamp}
     * @memberof ClimatologyHourObj
     */
    timestamp: Timestamp;
    /**
     * 
     * @type {CldCvr}
     * @memberof ClimatologyHourObj
     */
    cldCvr?: CldCvr;
    /**
     * 
     * @type {CldCvrSd}
     * @memberof ClimatologyHourObj
     */
    cldCvrSd?: CldCvrSd;
    /**
     * 
     * @type {DewPt}
     * @memberof ClimatologyHourObj
     */
    dewPt?: DewPt;
    /**
     * 
     * @type {DewPtSd}
     * @memberof ClimatologyHourObj
     */
    dewPtSd?: DewPtSd;
    /**
     * 
     * @type {FeelsLike}
     * @memberof ClimatologyHourObj
     */
    feelsLike?: FeelsLike;
    /**
     * 
     * @type {FeelsLikeSd}
     * @memberof ClimatologyHourObj
     */
    feelsLikeSd?: FeelsLikeSd;
    /**
     * 
     * @type {MslPres}
     * @memberof ClimatologyHourObj
     */
    mslPres?: MslPres;
    /**
     * 
     * @type {MslPresSd}
     * @memberof ClimatologyHourObj
     */
    mslPresSd?: MslPresSd;
    /**
     * 
     * @type {Precip}
     * @memberof ClimatologyHourObj
     */
    precip?: Precip;
    /**
     * 
     * @type {PrecipSd}
     * @memberof ClimatologyHourObj
     */
    precipSd?: PrecipSd;
    /**
     * 
     * @type {PrecipFreq}
     * @memberof ClimatologyHourObj
     */
    precipFreq?: PrecipFreq;
    /**
     * 
     * @type {PrecipFreq0}
     * @memberof ClimatologyHourObj
     */
    precipFreq0?: PrecipFreq0;
    /**
     * 
     * @type {PrecipFreq001To009}
     * @memberof ClimatologyHourObj
     */
    precipFreq001To009?: PrecipFreq001To009;
    /**
     * 
     * @type {PrecipFreq010To024}
     * @memberof ClimatologyHourObj
     */
    precipFreq010To024?: PrecipFreq010To024;
    /**
     * 
     * @type {PrecipFreq025To049}
     * @memberof ClimatologyHourObj
     */
    precipFreq025To049?: PrecipFreq025To049;
    /**
     * 
     * @type {PrecipFreq050To099}
     * @memberof ClimatologyHourObj
     */
    precipFreq050To099?: PrecipFreq050To099;
    /**
     * 
     * @type {PrecipFreq100To249}
     * @memberof ClimatologyHourObj
     */
    precipFreq100To249?: PrecipFreq100To249;
    /**
     * 
     * @type {PrecipFreq250To499}
     * @memberof ClimatologyHourObj
     */
    precipFreq250To499?: PrecipFreq250To499;
    /**
     * 
     * @type {PrecipFreq500Plus}
     * @memberof ClimatologyHourObj
     */
    precipFreq500Plus?: PrecipFreq500Plus;
    /**
     * 
     * @type {RadSolar}
     * @memberof ClimatologyHourObj
     */
    radSolar?: RadSolar;
    /**
     * 
     * @type {RadSolarSd}
     * @memberof ClimatologyHourObj
     */
    radSolarSd?: RadSolarSd;
    /**
     * 
     * @type {RelHum}
     * @memberof ClimatologyHourObj
     */
    relHum?: RelHum;
    /**
     * 
     * @type {RelHumSd}
     * @memberof ClimatologyHourObj
     */
    relHumSd?: RelHumSd;
    /**
     * 
     * @type {SfcPres}
     * @memberof ClimatologyHourObj
     */
    sfcPres?: SfcPres;
    /**
     * 
     * @type {SfcPresSd}
     * @memberof ClimatologyHourObj
     */
    sfcPresSd?: SfcPresSd;
    /**
     * 
     * @type {Snowfall}
     * @memberof ClimatologyHourObj
     */
    snowfall?: Snowfall;
    /**
     * 
     * @type {SnowfallSd}
     * @memberof ClimatologyHourObj
     */
    snowfallSd?: SnowfallSd;
    /**
     * 
     * @type {SpcHum}
     * @memberof ClimatologyHourObj
     */
    spcHum?: SpcHum;
    /**
     * 
     * @type {SpcHumSd}
     * @memberof ClimatologyHourObj
     */
    spcHumSd?: SpcHumSd;
    /**
     * 
     * @type {Temp}
     * @memberof ClimatologyHourObj
     */
    temp?: Temp;
    /**
     * 
     * @type {TempSd}
     * @memberof ClimatologyHourObj
     */
    tempSd?: TempSd;
    /**
     * 
     * @type {WetBulb}
     * @memberof ClimatologyHourObj
     */
    wetBulb?: WetBulb;
    /**
     * 
     * @type {WetBulbSd}
     * @memberof ClimatologyHourObj
     */
    wetBulbSd?: WetBulbSd;
    /**
     * 
     * @type {WindDir}
     * @memberof ClimatologyHourObj
     */
    windDir?: WindDir;
    /**
     * 
     * @type {WindDir80m}
     * @memberof ClimatologyHourObj
     */
    windDir80m?: WindDir80m;
    /**
     * 
     * @type {WindDir100m}
     * @memberof ClimatologyHourObj
     */
    windDir100m?: WindDir100m;
    /**
     * 
     * @type {WindSpd}
     * @memberof ClimatologyHourObj
     */
    windSpd?: WindSpd;
    /**
     * 
     * @type {WindSpdSd}
     * @memberof ClimatologyHourObj
     */
    windSpdSd?: WindSpdSd;
    /**
     * 
     * @type {WindVecSpd}
     * @memberof ClimatologyHourObj
     */
    windVecSpd?: WindVecSpd;
    /**
     * 
     * @type {WindVecSpd80m}
     * @memberof ClimatologyHourObj
     */
    windVecSpd80m?: WindVecSpd80m;
    /**
     * 
     * @type {WindVecSpd100m}
     * @memberof ClimatologyHourObj
     */
    windVecSpd100m?: WindVecSpd100m;
}
/**
 * Daily OnPoint™ climatological weather object
 * @export
 * @interface ClimatologyOnpointDayObj
 */
export interface ClimatologyOnpointDayObj {
    /**
     * 
     * @type {OnpointObj}
     * @memberof ClimatologyOnpointDayObj
     */
    location: OnpointObj;
    /**
     * 
     * @type {DateRangeObj}
     * @memberof ClimatologyOnpointDayObj
     */
    dateRange: DateRangeObj;
    /**
     * 
     * @type {FieldListDayObj}
     * @memberof ClimatologyOnpointDayObj
     */
    fieldList: FieldListDayObj;
    /**
     * 
     * @type {ClimatologyDayArr}
     * @memberof ClimatologyOnpointDayObj
     */
    climatology: ClimatologyDayArr;
}
/**
 * Hourly OnPoint™ climatological weather object
 * @export
 * @interface ClimatologyOnpointHourObj
 */
export interface ClimatologyOnpointHourObj {
    /**
     * 
     * @type {OnpointObj}
     * @memberof ClimatologyOnpointHourObj
     */
    location: OnpointObj;
    /**
     * 
     * @type {TimestampRangeObj}
     * @memberof ClimatologyOnpointHourObj
     */
    timestampRange: TimestampRangeObj;
    /**
     * 
     * @type {FieldListHourObj}
     * @memberof ClimatologyOnpointHourObj
     */
    fieldList: FieldListHourObj;
    /**
     * 
     * @type {ClimatologyHourArr}
     * @memberof ClimatologyOnpointHourObj
     */
    climatology: ClimatologyHourArr;
}
/**
 * Daily Latitude/Longitude climatological weather object
 * @export
 * @interface ClimatologyPointDayObj
 */
export interface ClimatologyPointDayObj {
    /**
     * 
     * @type {PointObj}
     * @memberof ClimatologyPointDayObj
     */
    location: PointObj;
    /**
     * 
     * @type {DateRangeObj}
     * @memberof ClimatologyPointDayObj
     */
    dateRange: DateRangeObj;
    /**
     * 
     * @type {FieldListDayObj}
     * @memberof ClimatologyPointDayObj
     */
    fieldList: FieldListDayObj;
    /**
     * 
     * @type {ClimatologyDayArr}
     * @memberof ClimatologyPointDayObj
     */
    climatology: ClimatologyDayArr;
}
/**
 * Hourly Latitude/Longitude climatological weather object
 * @export
 * @interface ClimatologyPointHourObj
 */
export interface ClimatologyPointHourObj {
    /**
     * 
     * @type {PointObj}
     * @memberof ClimatologyPointHourObj
     */
    location: PointObj;
    /**
     * 
     * @type {TimestampRangeObj}
     * @memberof ClimatologyPointHourObj
     */
    timestampRange: TimestampRangeObj;
    /**
     * 
     * @type {FieldListHourObj}
     * @memberof ClimatologyPointHourObj
     */
    fieldList: FieldListHourObj;
    /**
     * 
     * @type {ClimatologyHourArr}
     * @memberof ClimatologyPointHourObj
     */
    climatology: ClimatologyHourArr;
}
/**
 * Daily Postcode climatological weather object
 * @export
 * @interface ClimatologyPostcodeDayObj
 */
export interface ClimatologyPostcodeDayObj {
    /**
     * 
     * @type {PostcodeObj}
     * @memberof ClimatologyPostcodeDayObj
     */
    location: PostcodeObj;
    /**
     * 
     * @type {DateRangeObj}
     * @memberof ClimatologyPostcodeDayObj
     */
    dateRange: DateRangeObj;
    /**
     * 
     * @type {FieldListDayObj}
     * @memberof ClimatologyPostcodeDayObj
     */
    fieldList: FieldListDayObj;
    /**
     * 
     * @type {ClimatologyDayArr}
     * @memberof ClimatologyPostcodeDayObj
     */
    climatology: ClimatologyDayArr;
}
/**
 * Hourly Postcode climatological weather object
 * @export
 * @interface ClimatologyPostcodeHourObj
 */
export interface ClimatologyPostcodeHourObj {
    /**
     * 
     * @type {PostcodeObj}
     * @memberof ClimatologyPostcodeHourObj
     */
    location: PostcodeObj;
    /**
     * 
     * @type {TimestampRangeObj}
     * @memberof ClimatologyPostcodeHourObj
     */
    timestampRange: TimestampRangeObj;
    /**
     * 
     * @type {FieldListHourObj}
     * @memberof ClimatologyPostcodeHourObj
     */
    fieldList: FieldListHourObj;
    /**
     * 
     * @type {ClimatologyHourArr}
     * @memberof ClimatologyPostcodeHourObj
     */
    climatology: ClimatologyHourArr;
}
/**
 * An [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
 * @export
 */
export type CountryCode = string
/**
 * A common country name.
 * @export
 */
export type CountryName = string
/**
 * A date formatted as an RFC3339 date value.
 * @export
 */
export type Date = string
/**
 * An end date for a date range formatted as an RFC3339 date value.
 * @export
 */
export type DateEnd = string
/**
 * A date range object.
 * @export
 * @interface DateRangeObj
 */
export interface DateRangeObj {
    /**
     * 
     * @type {DateStart}
     * @memberof DateRangeObj
     */
    dateStart: DateStart;
    /**
     * 
     * @type {DateEnd}
     * @memberof DateRangeObj
     */
    dateEnd: DateEnd;
}
/**
 * A start date for a date range formatted as an RFC3339 date value.
 * @export
 */
export type DateStart = string
/**
 * Dew Point in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type DewPt = number
/**
 * Average Dew Point in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type DewPtAvg = number
/**
 * The Standard Deviation of Average Dew Point in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type DewPtAvgSd = number
/**
 * Maximum Dew Point in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type DewPtMax = number
/**
 * The Standard Deviation of Maximum Dew Point in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type DewPtMaxSd = number
/**
 * Minimum Dew Point in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type DewPtMin = number
/**
 * The Standard Deviation of Minimum Dew Point in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type DewPtMinSd = number
/**
 * The Standard Deviation of Dew Point in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type DewPtSd = number
/**
 * A distance from the provided point in miles.
 * @export
 */
export type Distance = number
/**
 * The difference in population for the whole Designated Market Area and the population for the postcode represented by this sample point.
 * @export
 */
export type DistancePop = number
/**
 * A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
 * @export
 */
export type DmaId = number
/**
 * A Designated Market Area name.
 * @export
 */
export type DmaName = string
/**
 * A Designated Market Area location metadata object
 * @export
 * @interface DmaObj
 */
export interface DmaObj {
    /**
     * 
     * @type {DmaId}
     * @memberof DmaObj
     */
    dmaId: DmaId;
    /**
     * 
     * @type {DmaName}
     * @memberof DmaObj
     */
    dmaName: DmaName;
    /**
     * 
     * @type {Timezone}
     * @memberof DmaObj
     */
    timezone: Timezone;
    /**
     * 
     * @type {Population}
     * @memberof DmaObj
     */
    population: Population;
    /**
     * 
     * @type {CountryCode}
     * @memberof DmaObj
     */
    countryCode: CountryCode;
    /**
     * 
     * @type {CountryName}
     * @memberof DmaObj
     */
    countryName: CountryName;
    /**
     * 
     * @type {SamplePoints}
     * @memberof DmaObj
     */
    samplePoints: SamplePoints;
    /**
     * 
     * @type {Grid}
     * @memberof DmaObj
     */
    grid: Grid;
}
/**
 * The elevation above sea level of a location in meters
 * @export
 */
export type Elevation = number
/**
 * 
 * @export
 * @interface ErrorObj
 */
export interface ErrorObj {
    /**
     * 
     * @type {number}
     * @memberof ErrorObj
     */
    errorCode?: number;
    /**
     * 
     * @type {string}
     * @memberof ErrorObj
     */
    errorMessage?: string;
}
/**
 * Feels Like Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type FeelsLike = number
/**
 * Average Feels Like Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type FeelsLikeAvg = number
/**
 * The Standard Deviation of Average Feels Like Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type FeelsLikeAvgSd = number
/**
 * Maximum Feels Like Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type FeelsLikeMax = number
/**
 * The Standard Deviation of Maximum Feels Like Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type FeelsLikeMaxSd = number
/**
 * Minimum Feels Like Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type FeelsLikeMin = number
/**
 * The Standard Deviation of Minimum Feels Like Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type FeelsLikeMinSd = number
/**
 * The Standard Deviation of Feels Like Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type FeelsLikeSd = number
/**
 * A list of returned field names the associated units.
 * @export
 * @interface FieldListDayObj
 */
export interface FieldListDayObj {
    /**
     * 
     * @type {Fields}
     * @memberof FieldListDayObj
     */
    fields: Fields;
}
/**
 * A list of returned field names the associated units.
 * @export
 * @interface FieldListHourObj
 */
export interface FieldListHourObj {
    /**
     * 
     * @type {Fields}
     * @memberof FieldListHourObj
     */
    fields: Fields;
}
/**
 * 
 * @export
 * @interface Fields
 */
export interface Fields extends null<String, string> {
    [key: string]: string;

}
/**
 * The OnPoint™ grid on which the resource exists.
 * @export
 * @enum {string}
 */
export enum Grid {
    GLOBALGRID = <any> 'GLOBAL_GRID',
    NORTHAMERICAGRID = <any> 'NORTH_AMERICA_GRID'
}
/**
 * A latitude value between -90° and 90°.
 * @export
 */
export type Latitude = number
/**
 * A longitude value between -180° (West) and 180° (East).
 * @export
 */
export type Longitude = number
/**
 * Mean Sea Level Pressure in millibars.
 * @export
 */
export type MslPres = number
/**
 * Average Mean Sea Level Pressure in millibars.
 * @export
 */
export type MslPresAvg = number
/**
 * The Standard Deviation of Average Mean Sea Level Pressure in millibars.
 * @export
 */
export type MslPresAvgSd = number
/**
 * Maximum Mean Sea Level Pressure in millibars.
 * @export
 */
export type MslPresMax = number
/**
 * The Standard Deviation of Maximum Mean Sea Level Pressure in millibars.
 * @export
 */
export type MslPresMaxSd = number
/**
 * Minimum Mean Sea Level Pressure in millibars.
 * @export
 */
export type MslPresMin = number
/**
 * The Standard Deviation of Minimum Mean Sea Level Pressure in millibars.
 * @export
 */
export type MslPresMinSd = number
/**
 * The Standard Deviation of Mean Sea Level Pressure in millibars.
 * @export
 */
export type MslPresSd = number
/**
 * An OnPoint™ ID.
 * @export
 */
export type OnpointId = number
/**
 * An OnPoint™ point location metadata object
 * @export
 * @interface OnpointObj
 */
export interface OnpointObj {
    /**
     * 
     * @type {OnpointId}
     * @memberof OnpointObj
     */
    onpointId: OnpointId;
    /**
     * 
     * @type {Latitude}
     * @memberof OnpointObj
     */
    latitude: Latitude;
    /**
     * 
     * @type {Longitude}
     * @memberof OnpointObj
     */
    longitude: Longitude;
    /**
     * 
     * @type {Timezone}
     * @memberof OnpointObj
     */
    timezone: Timezone;
    /**
     * 
     * @type {CountryCode}
     * @memberof OnpointObj
     */
    countryCode?: CountryCode;
    /**
     * 
     * @type {CountryName}
     * @memberof OnpointObj
     */
    countryName?: CountryName;
    /**
     * 
     * @type {SubdivCode}
     * @memberof OnpointObj
     */
    subdivCode?: SubdivCode;
    /**
     * 
     * @type {SubdivName}
     * @memberof OnpointObj
     */
    subdivName?: SubdivName;
    /**
     * 
     * @type {Grid}
     * @memberof OnpointObj
     */
    grid: Grid;
    /**
     * 
     * @type {Elevation}
     * @memberof OnpointObj
     */
    elevation: Elevation;
}
/**
 * Metadata object for a postcode
 * @export
 * @interface PointObj
 */
export interface PointObj {
    /**
     * 
     * @type {Latitude}
     * @memberof PointObj
     */
    latitude: Latitude;
    /**
     * 
     * @type {Longitude}
     * @memberof PointObj
     */
    longitude: Longitude;
    /**
     * 
     * @type {Timezone}
     * @memberof PointObj
     */
    timezone: Timezone;
    /**
     * 
     * @type {CountryCode}
     * @memberof PointObj
     */
    countryCode?: CountryCode;
    /**
     * 
     * @type {CountryName}
     * @memberof PointObj
     */
    countryName?: CountryName;
    /**
     * 
     * @type {SubdivCode}
     * @memberof PointObj
     */
    subdivCode?: SubdivCode;
    /**
     * 
     * @type {SubdivName}
     * @memberof PointObj
     */
    subdivName?: SubdivName;
    /**
     * 
     * @type {BoundingPoints}
     * @memberof PointObj
     */
    boundingPoints: BoundingPoints;
    /**
     * 
     * @type {Grid}
     * @memberof PointObj
     */
    grid: Grid;
    /**
     * 
     * @type {Elevation}
     * @memberof PointObj
     */
    elevation: Elevation;
}
/**
 * The population as represented in the 2010 census.
 * @export
 */
export type Population = number
/**
 * A postcode string.
 * @export
 */
export type Postcode = string
/**
 * A postcode location metadata object
 * @export
 * @interface PostcodeObj
 */
export interface PostcodeObj {
    /**
     * 
     * @type {Postcode}
     * @memberof PostcodeObj
     */
    postcode: Postcode;
    /**
     * 
     * @type {Latitude}
     * @memberof PostcodeObj
     */
    latitude: Latitude;
    /**
     * 
     * @type {Longitude}
     * @memberof PostcodeObj
     */
    longitude: Longitude;
    /**
     * 
     * @type {Timezone}
     * @memberof PostcodeObj
     */
    timezone: Timezone;
    /**
     * 
     * @type {CountryCode}
     * @memberof PostcodeObj
     */
    countryCode: CountryCode;
    /**
     * 
     * @type {CountryName}
     * @memberof PostcodeObj
     */
    countryName: CountryName;
    /**
     * 
     * @type {SubdivCode}
     * @memberof PostcodeObj
     */
    subdivCode?: SubdivCode;
    /**
     * 
     * @type {SubdivName}
     * @memberof PostcodeObj
     */
    subdivName?: SubdivName;
    /**
     * 
     * @type {BoundingPoints}
     * @memberof PostcodeObj
     */
    boundingPoints: BoundingPoints;
    /**
     * 
     * @type {Grid}
     * @memberof PostcodeObj
     */
    grid: Grid;
    /**
     * 
     * @type {Elevation}
     * @memberof PostcodeObj
     */
    elevation: Elevation;
}
/**
 * Total precipitation in inches (imperial) or centimeters (metric, si).
 * @export
 */
export type Precip = number
/**
 * The frequency of precipitation as a percent value.
 * @export
 */
export type PrecipFreq = number
/**
 * The frequency of zero precipitation as a percent value.
 * @export
 */
export type PrecipFreq0 = number
/**
 * The frequency of precipitation greater than 0 and less than 0.10 inches as a percent value.
 * @export
 */
export type PrecipFreq001To009 = number
/**
 * The frequency of precipitation greater than 0.10 and less than 0.25 inches as a percent value.
 * @export
 */
export type PrecipFreq010To024 = number
/**
 * The frequency of precipitation greater than 0.25 and less than 0.50 inches as a percent value.
 * @export
 */
export type PrecipFreq025To049 = number
/**
 * The frequency of precipitation greater than 0.50 and less than 1.00 inches as a percent value.
 * @export
 */
export type PrecipFreq050To099 = number
/**
 * The frequency of precipitation greater than 1.00 and less than 2.50 inches as a percent value.
 * @export
 */
export type PrecipFreq100To249 = number
/**
 * The frequency of precipitation greater than 2.50 and less than 5.00 inches as a percent value.
 * @export
 */
export type PrecipFreq250To499 = number
/**
 * The frequency of precipitation greater than 5.00 inches as a percent value.
 * @export
 */
export type PrecipFreq500Plus = number
/**
 * The Standard Deviation of Total precipitation in inches (imperial) or centimeters (metric, si).
 * @export
 */
export type PrecipSd = number
/**
 * Solar Radiation in watts per square meter.
 * @export
 */
export type RadSolar = number
/**
 * Average Solar Radiation in watts per square meter.
 * @export
 */
export type RadSolarAvg = number
/**
 * The Standard Deviation of Average Solar Radiation in watts per square meter.
 * @export
 */
export type RadSolarAvgSd = number
/**
 * Maximum Solar Radiation in watts per square meter.
 * @export
 */
export type RadSolarMax = number
/**
 * The Standard Deviation of Maximum Solar Radiation in watts per square meter.
 * @export
 */
export type RadSolarMaxSd = number
/**
 * Minimum Solar Radiation in watts per square meter.
 * @export
 */
export type RadSolarMin = number
/**
 * The Standard Deviation of Minimum Solar Radiation in watts per square meter.
 * @export
 */
export type RadSolarMinSd = number
/**
 * The Standard Deviation of Solar Radiation in watts per square meter.
 * @export
 */
export type RadSolarSd = number
/**
 * Total Solar Radiation in watts per square meter.
 * @export
 */
export type RadSolarTot = number
/**
 * The Standard Deviation of Total Solar Radiation in watts per square meter.
 * @export
 */
export type RadSolarTotSd = number
/**
 * Relative humidity as a percent value.
 * @export
 */
export type RelHum = number
/**
 * Average Relative humidity as a percent value.
 * @export
 */
export type RelHumAvg = number
/**
 * The Standard Deviation of Average Relative humidity as a percent value.
 * @export
 */
export type RelHumAvgSd = number
/**
 * Maximum Relative humidity as a percent value.
 * @export
 */
export type RelHumMax = number
/**
 * The Standard Deviation of Maximum Relative humidity as a percent value.
 * @export
 */
export type RelHumMaxSd = number
/**
 * Minimum Relative humidity as a percent value.
 * @export
 */
export type RelHumMin = number
/**
 * The Standard Deviation of Minimum Relative humidity as a percent value.
 * @export
 */
export type RelHumMinSd = number
/**
 * The Standard Deviation of Relative humidity as a percent value.
 * @export
 */
export type RelHumSd = number
/**
 * A list of OnPoint™ points used for interpolation for the Designated Market Area. These points are the OnPoint™ ID closest to the centroid of the 10 most populous  postcodes within the target DMA.
 * @export
 */
export type SamplePoints = Array<SamplePointsInner>
/**
 * 
 * @export
 * @interface SamplePointsInner
 */
export interface SamplePointsInner {
    /**
     * 
     * @type {OnpointId}
     * @memberof SamplePointsInner
     */
    onpointId: OnpointId;
    /**
     * 
     * @type {Latitude}
     * @memberof SamplePointsInner
     */
    latitude: Latitude;
    /**
     * 
     * @type {Longitude}
     * @memberof SamplePointsInner
     */
    longitude: Longitude;
    /**
     * 
     * @type {Grid}
     * @memberof SamplePointsInner
     */
    grid: Grid;
    /**
     * 
     * @type {DistancePop}
     * @memberof SamplePointsInner
     */
    distance: DistancePop;
    /**
     * 
     * @type {Elevation}
     * @memberof SamplePointsInner
     */
    elevation: Elevation;
}
/**
 * Surface pressure in millibars.
 * @export
 */
export type SfcPres = number
/**
 * Average Surface pressure in millibars.
 * @export
 */
export type SfcPresAvg = number
/**
 * The Standard Deviation of Average Surface pressure in millibars.
 * @export
 */
export type SfcPresAvgSd = number
/**
 * Maximum Surface pressure in millibars.
 * @export
 */
export type SfcPresMax = number
/**
 * The Standard Deviation of Maximum Surface pressure in millibars.
 * @export
 */
export type SfcPresMaxSd = number
/**
 * Minimum Surface pressure in millibars.
 * @export
 */
export type SfcPresMin = number
/**
 * The Standard Deviation of Minimum Surface pressure in millibars.
 * @export
 */
export type SfcPresMinSd = number
/**
 * The Standard Deviation of Surface pressure in millibars.
 * @export
 */
export type SfcPresSd = number
/**
 * Total Snow depth in inches (imperial) or centimeters (metric, si).
 * @export
 */
export type SnowDepth = number
/**
 * The Standard Deviation of Total Snow depth in inches (imperial) or centimeters (metric, si).
 * @export
 */
export type SnowDepthSd = number
/**
 * Total snowfall in inches (imperial) or centimeters (metric, si).
 * @export
 */
export type Snowfall = number
/**
 * The frequency of snowfall as a percent value.
 * @export
 */
export type SnowfallFreq = number
/**
 * The frequency of zero snowfall as a percent value.
 * @export
 */
export type SnowfallFreq0 = number
/**
 * The frequency of snowfall greater than 0 and less than 1.0 inches as a percent value.
 * @export
 */
export type SnowfallFreq001To009 = number
/**
 * The frequency of snowfall greater than 1.0 and less than 2.5 inches as a percent value.
 * @export
 */
export type SnowfallFreq010To024 = number
/**
 * The frequency of snowfall greater than 2.5 and less than 5.0 inches as a percent value.
 * @export
 */
export type SnowfallFreq025To049 = number
/**
 * The frequency of snowfall greater than 5.0 and less than 10.0 inches as a percent value.
 * @export
 */
export type SnowfallFreq050To099 = number
/**
 * The frequency of snowfall greater than 10.0 and less than 15.0 inches as a percent value.
 * @export
 */
export type SnowfallFreq100To149 = number
/**
 * The frequency of snowfall greater than 15.0 and less than 25.0 inches as a percent value.
 * @export
 */
export type SnowfallFreq150To249 = number
/**
 * The frequency of snowfall greater than 25.0 inches as a percent value.
 * @export
 */
export type SnowfallFreq250Plus = number
/**
 * The Standard Deviation of Total snowfall in inches (imperial) or centimeters (metric, si).
 * @export
 */
export type SnowfallSd = number
/**
 * Specific humidity in grams per kilograms.
 * @export
 */
export type SpcHum = number
/**
 * Average Specific humidity in grams per kilograms.
 * @export
 */
export type SpcHumAvg = number
/**
 * The Standard Deviation of Average Specific humidity in grams per kilograms.
 * @export
 */
export type SpcHumAvgSd = number
/**
 * Maximum Specific humidity in grams per kilograms.
 * @export
 */
export type SpcHumMax = number
/**
 * The Standard Deviation of Maximum Specific humidity in grams per kilograms.
 * @export
 */
export type SpcHumMaxSd = number
/**
 * Minimum Specific humidity in grams per kilograms.
 * @export
 */
export type SpcHumMin = number
/**
 * The Standard Deviation of Minimum Specific humidity in grams per kilograms.
 * @export
 */
export type SpcHumMinSd = number
/**
 * The Standard Deviation of Specific humidity in grams per kilograms.
 * @export
 */
export type SpcHumSd = number
/**
 * An ISO 3166-2 country subdivision code.
 * @export
 */
export type SubdivCode = string
/**
 * A common country subdivision name.
 * @export
 */
export type SubdivName = string
/**
 * Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type Temp = number
/**
 * Average Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type TempAvg = number
/**
 * The Standard Deviation of Average Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type TempAvgSd = number
/**
 * Maximum Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type TempMax = number
/**
 * The Standard Deviation of Maximum Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type TempMaxSd = number
/**
 * Minimum Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type TempMin = number
/**
 * The Standard Deviation of Minimum Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type TempMinSd = number
/**
 * The Standard Deviation of Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type TempSd = number
/**
 * A timestamp formatted as an RFC3339 date-time value.
 * @export
 */
export type Timestamp = Date
/**
 * An end timestamp for a timestamp range formatted as an RFC3339 date-time value.
 * @export
 */
export type TimestampEnd = Date
/**
 * A timestamp range object
 * @export
 * @interface TimestampRangeObj
 */
export interface TimestampRangeObj {
    /**
     * 
     * @type {TimestampStart}
     * @memberof TimestampRangeObj
     */
    timestampStart: TimestampStart;
    /**
     * 
     * @type {TimestampEnd}
     * @memberof TimestampRangeObj
     */
    timestampEnd: TimestampEnd;
}
/**
 * A start timestamp for a timestamp range formatted as an RFC3339 date-time value.
 * @export
 */
export type TimestampStart = Date
/**
 * An Olson timezone ID.
 * @export
 */
export type Timezone = string
/**
 * Wet Bulb Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type WetBulb = number
/**
 * Average Wet Bulb Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type WetBulbAvg = number
/**
 * The Standard Deviation of Average Wet Bulb Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type WetBulbAvgSd = number
/**
 * Maximum Wet Bulb Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type WetBulbMax = number
/**
 * The Standard Deviation of Maximum Wet Bulb Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type WetBulbMaxSd = number
/**
 * Minimum Wet Bulb Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type WetBulbMin = number
/**
 * The Standard Deviation of Minimum Wet Bulb Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type WetBulbMinSd = number
/**
 * The Standard Deviation of Wet Bulb Temperature in Degrees Fahrenheit (imperial), Celsius (metric), or Kelvin (si).
 * @export
 */
export type WetBulbSd = number
/**
 * Wind direction at 10 meters in Degrees (0 or 360 = North, 90 = East, South = 180, West = 270).
 * @export
 */
export type WindDir = number
/**
 * Wind direction at 100 meters in Degrees (0 or 360 = North, 90 = East, South = 180, West = 270).
 * @export
 */
export type WindDir100m = number
/**
 * Average Wind direction at 100 meters in Degrees (0 or 360 = North, 90 = East, South = 180, West = 270).
 * @export
 */
export type WindDir100mAvg = number
/**
 * Wind direction at 80 meters in Degrees (0 or 360 = North, 90 = East, South = 180, West = 270).
 * @export
 */
export type WindDir80m = number
/**
 * Average Wind direction at 80 meters in Degrees (0 or 360 = North, 90 = East, South = 180, West = 270).
 * @export
 */
export type WindDir80mAvg = number
/**
 * Average Wind direction at 10 meters in Degrees (0 or 360 = North, 90 = East, South = 180, West = 270).
 * @export
 */
export type WindDirAvg = number
/**
 * Wind speed at 10 meters in miles per hour (imperial) or km/hour (metric, si).
 * @export
 */
export type WindSpd = number
/**
 * Average Wind speed at 10 meters in miles per hour (imperial) or km/hour (metric, si).
 * @export
 */
export type WindSpdAvg = number
/**
 * The Standard Deviation of Average Wind speed at 10 meters in miles per hour (imperial) or km/hour (metric, si).
 * @export
 */
export type WindSpdAvgSd = number
/**
 * Maximum Wind speed at 10 meters in miles per hour (imperial) or km/hour (metric, si).
 * @export
 */
export type WindSpdMax = number
/**
 * The Standard Deviation of Maximum Wind speed at 10 meters in miles per hour (imperial) or km/hour (metric, si).
 * @export
 */
export type WindSpdMaxSd = number
/**
 * Minimum Wind speed at 10 meters in miles per hour (imperial) or km/hour (metric, si).
 * @export
 */
export type WindSpdMin = number
/**
 * The Standard Deviation of Minimum Wind speed at 10 meters in miles per hour (imperial) or km/hour (metric, si).
 * @export
 */
export type WindSpdMinSd = number
/**
 * The Standard Deviation of Wind speed at 10 meters in miles per hour (imperial) or km/hour (metric, si).
 * @export
 */
export type WindSpdSd = number
/**
 * Vector wind speed at 10 meters in miles per hour (imperial) or km/hour (metric, si).
 * @export
 */
export type WindVecSpd = number
/**
 * Vector wind speed at 100 meters in miles per hour (imperial) or km/hour (metric, si).
 * @export
 */
export type WindVecSpd100m = number
/**
 * Vector wind speed at 80 meters in miles per hour (imperial) or km/hour (metric, si).
 * @export
 */
export type WindVecSpd80m = number
/**
 * DmasApi - fetch parameter creator
 * @export
 */
export const DmasApiFetchParamCreator = function (configuration?: Configuration) {
    return {
        /**
         * Returns a single day of climatological weather data for a Designated Market Area.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of weather climatology for a DMA.
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdDaysDateGet(dmaId: number, date: string, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'dmaId' is not null or undefined
            if (dmaId === null || dmaId === undefined) {
                throw new RequiredError('dmaId','Required parameter dmaId was null or undefined when calling dmasDmaIdDaysDateGet.');
            }
            // verify required parameter 'date' is not null or undefined
            if (date === null || date === undefined) {
                throw new RequiredError('date','Required parameter date was null or undefined when calling dmasDmaIdDaysDateGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling dmasDmaIdDaysDateGet.');
            }
            const localVarPath = `/dmas/{dmaId}/days/{date}`
                .replace(`{${"dmaId"}}`, encodeURIComponent(String(dmaId)))
                .replace(`{${"date"}}`, encodeURIComponent(String(date)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a contiguous range of daily climatological weather data for a Designated Market Area. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily weather climatology for a DMA.
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdDaysDateStartdateEndGet(dmaId: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'dmaId' is not null or undefined
            if (dmaId === null || dmaId === undefined) {
                throw new RequiredError('dmaId','Required parameter dmaId was null or undefined when calling dmasDmaIdDaysDateStartdateEndGet.');
            }
            // verify required parameter 'dateStart' is not null or undefined
            if (dateStart === null || dateStart === undefined) {
                throw new RequiredError('dateStart','Required parameter dateStart was null or undefined when calling dmasDmaIdDaysDateStartdateEndGet.');
            }
            // verify required parameter 'dateEnd' is not null or undefined
            if (dateEnd === null || dateEnd === undefined) {
                throw new RequiredError('dateEnd','Required parameter dateEnd was null or undefined when calling dmasDmaIdDaysDateStartdateEndGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling dmasDmaIdDaysDateStartdateEndGet.');
            }
            const localVarPath = `/dmas/{dmaId}/days/{dateStart},{dateEnd}`
                .replace(`{${"dmaId"}}`, encodeURIComponent(String(dmaId)))
                .replace(`{${"dateStart"}}`, encodeURIComponent(String(dateStart)))
                .replace(`{${"dateEnd"}}`, encodeURIComponent(String(dateEnd)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a single hour of climatological weather data for a Designated Market Area.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of weather climatology for a DMA
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdHoursTimestampGet(dmaId: number, timestamp: Date, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'dmaId' is not null or undefined
            if (dmaId === null || dmaId === undefined) {
                throw new RequiredError('dmaId','Required parameter dmaId was null or undefined when calling dmasDmaIdHoursTimestampGet.');
            }
            // verify required parameter 'timestamp' is not null or undefined
            if (timestamp === null || timestamp === undefined) {
                throw new RequiredError('timestamp','Required parameter timestamp was null or undefined when calling dmasDmaIdHoursTimestampGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling dmasDmaIdHoursTimestampGet.');
            }
            const localVarPath = `/dmas/{dmaId}/hours/{timestamp}`
                .replace(`{${"dmaId"}}`, encodeURIComponent(String(dmaId)))
                .replace(`{${"timestamp"}}`, encodeURIComponent(String(timestamp)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a contiguous range of hourly climatological weather data for a Designated Market Area. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly weather climatology for a DMA.
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdHoursTimestampStarttimestampEndGet(dmaId: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'dmaId' is not null or undefined
            if (dmaId === null || dmaId === undefined) {
                throw new RequiredError('dmaId','Required parameter dmaId was null or undefined when calling dmasDmaIdHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'timestampStart' is not null or undefined
            if (timestampStart === null || timestampStart === undefined) {
                throw new RequiredError('timestampStart','Required parameter timestampStart was null or undefined when calling dmasDmaIdHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'timestampEnd' is not null or undefined
            if (timestampEnd === null || timestampEnd === undefined) {
                throw new RequiredError('timestampEnd','Required parameter timestampEnd was null or undefined when calling dmasDmaIdHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling dmasDmaIdHoursTimestampStarttimestampEndGet.');
            }
            const localVarPath = `/dmas/{dmaId}/hours/{timestampStart},{timestampEnd}`
                .replace(`{${"dmaId"}}`, encodeURIComponent(String(dmaId)))
                .replace(`{${"timestampStart"}}`, encodeURIComponent(String(timestampStart)))
                .replace(`{${"timestampEnd"}}`, encodeURIComponent(String(timestampEnd)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
    }
};

/**
 * DmasApi - functional programming interface
 * @export
 */
export const DmasApiFp = function(configuration?: Configuration) {
    return {
        /**
         * Returns a single day of climatological weather data for a Designated Market Area.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of weather climatology for a DMA.
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdDaysDateGet(dmaId: number, date: string, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<ClimatologyDmaDayObj> {
            const localVarFetchArgs = DmasApiFetchParamCreator(configuration).dmasDmaIdDaysDateGet(dmaId, date, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a contiguous range of daily climatological weather data for a Designated Market Area. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily weather climatology for a DMA.
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdDaysDateStartdateEndGet(dmaId: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<ClimatologyDmaDayObj> {
            const localVarFetchArgs = DmasApiFetchParamCreator(configuration).dmasDmaIdDaysDateStartdateEndGet(dmaId, dateStart, dateEnd, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a single hour of climatological weather data for a Designated Market Area.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of weather climatology for a DMA
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdHoursTimestampGet(dmaId: number, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<ClimatologyDmaHourObj> {
            const localVarFetchArgs = DmasApiFetchParamCreator(configuration).dmasDmaIdHoursTimestampGet(dmaId, timestamp, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a contiguous range of hourly climatological weather data for a Designated Market Area. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly weather climatology for a DMA.
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdHoursTimestampStarttimestampEndGet(dmaId: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<ClimatologyDmaHourObj> {
            const localVarFetchArgs = DmasApiFetchParamCreator(configuration).dmasDmaIdHoursTimestampStarttimestampEndGet(dmaId, timestampStart, timestampEnd, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
    }
};

/**
 * DmasApi - factory interface
 * @export
 */
export const DmasApiFactory = function (configuration?: Configuration, fetch?: FetchAPI, basePath?: string) {
    return {
        /**
         * Returns a single day of climatological weather data for a Designated Market Area.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of weather climatology for a DMA.
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdDaysDateGet(dmaId: number, date: string, fields: Array<string>, unitScale?: string, options?: any) {
            return DmasApiFp(configuration).dmasDmaIdDaysDateGet(dmaId, date, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a contiguous range of daily climatological weather data for a Designated Market Area. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily weather climatology for a DMA.
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdDaysDateStartdateEndGet(dmaId: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any) {
            return DmasApiFp(configuration).dmasDmaIdDaysDateStartdateEndGet(dmaId, dateStart, dateEnd, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a single hour of climatological weather data for a Designated Market Area.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of weather climatology for a DMA
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdHoursTimestampGet(dmaId: number, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any) {
            return DmasApiFp(configuration).dmasDmaIdHoursTimestampGet(dmaId, timestamp, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a contiguous range of hourly climatological weather data for a Designated Market Area. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly weather climatology for a DMA.
         * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        dmasDmaIdHoursTimestampStarttimestampEndGet(dmaId: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any) {
            return DmasApiFp(configuration).dmasDmaIdHoursTimestampStarttimestampEndGet(dmaId, timestampStart, timestampEnd, fields, unitScale, options)(fetch, basePath);
        },
    };
};

/**
 * DmasApi - object-oriented interface
 * @export
 * @class DmasApi
 * @extends {BaseAPI}
 */
export class DmasApi extends BaseAPI {
    /**
     * Returns a single day of climatological weather data for a Designated Market Area.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A day of weather climatology for a DMA.
     * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
     * @param {string} date An date formatted as a RFC3339 date value.
     * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof DmasApi
     */
    public dmasDmaIdDaysDateGet(dmaId: number, date: string, fields: Array<string>, unitScale?: string, options?: any) {
        return DmasApiFp(this.configuration).dmasDmaIdDaysDateGet(dmaId, date, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a contiguous range of daily climatological weather data for a Designated Market Area. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A contiguous range of daily weather climatology for a DMA.
     * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
     * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
     * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
     * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof DmasApi
     */
    public dmasDmaIdDaysDateStartdateEndGet(dmaId: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any) {
        return DmasApiFp(this.configuration).dmasDmaIdDaysDateStartdateEndGet(dmaId, dateStart, dateEnd, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a single hour of climatological weather data for a Designated Market Area.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary An hour of weather climatology for a DMA
     * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
     * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
     * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof DmasApi
     */
    public dmasDmaIdHoursTimestampGet(dmaId: number, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any) {
        return DmasApiFp(this.configuration).dmasDmaIdHoursTimestampGet(dmaId, timestamp, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a contiguous range of hourly climatological weather data for a Designated Market Area. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A contiguous range of hourly weather climatology for a DMA.
     * @param {number} dmaId A [Designated Market Area ID](https://developer.weathersourceapis.com/apis/supported-dmas/).
     * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
     * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
     * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof DmasApi
     */
    public dmasDmaIdHoursTimestampStarttimestampEndGet(dmaId: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any) {
        return DmasApiFp(this.configuration).dmasDmaIdHoursTimestampStarttimestampEndGet(dmaId, timestampStart, timestampEnd, fields, unitScale, options)(this.fetch, this.basePath);
    }

}
/**
 * OnpointsApi - fetch parameter creator
 * @export
 */
export const OnpointsApiFetchParamCreator = function (configuration?: Configuration) {
    return {
        /**
         * Returns a single day of climatological weather data for an OnPoint™ point.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of weather climatology for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdDaysDateGet(onpointId: number, date: string, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'onpointId' is not null or undefined
            if (onpointId === null || onpointId === undefined) {
                throw new RequiredError('onpointId','Required parameter onpointId was null or undefined when calling onpointsOnpointIdDaysDateGet.');
            }
            // verify required parameter 'date' is not null or undefined
            if (date === null || date === undefined) {
                throw new RequiredError('date','Required parameter date was null or undefined when calling onpointsOnpointIdDaysDateGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling onpointsOnpointIdDaysDateGet.');
            }
            const localVarPath = `/onpoints/{onpointId}/days/{date}`
                .replace(`{${"onpointId"}}`, encodeURIComponent(String(onpointId)))
                .replace(`{${"date"}}`, encodeURIComponent(String(date)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a contiguous range of daily climatological weather data for an OnPoint™ point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily weather climatology for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdDaysDateStartdateEndGet(onpointId: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'onpointId' is not null or undefined
            if (onpointId === null || onpointId === undefined) {
                throw new RequiredError('onpointId','Required parameter onpointId was null or undefined when calling onpointsOnpointIdDaysDateStartdateEndGet.');
            }
            // verify required parameter 'dateStart' is not null or undefined
            if (dateStart === null || dateStart === undefined) {
                throw new RequiredError('dateStart','Required parameter dateStart was null or undefined when calling onpointsOnpointIdDaysDateStartdateEndGet.');
            }
            // verify required parameter 'dateEnd' is not null or undefined
            if (dateEnd === null || dateEnd === undefined) {
                throw new RequiredError('dateEnd','Required parameter dateEnd was null or undefined when calling onpointsOnpointIdDaysDateStartdateEndGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling onpointsOnpointIdDaysDateStartdateEndGet.');
            }
            const localVarPath = `/onpoints/{onpointId}/days/{dateStart},{dateEnd}`
                .replace(`{${"onpointId"}}`, encodeURIComponent(String(onpointId)))
                .replace(`{${"dateStart"}}`, encodeURIComponent(String(dateStart)))
                .replace(`{${"dateEnd"}}`, encodeURIComponent(String(dateEnd)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a single hour of climatological weather data for an OnPoint™ point.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of weather climatology for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdHoursTimestampGet(onpointId: number, timestamp: Date, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'onpointId' is not null or undefined
            if (onpointId === null || onpointId === undefined) {
                throw new RequiredError('onpointId','Required parameter onpointId was null or undefined when calling onpointsOnpointIdHoursTimestampGet.');
            }
            // verify required parameter 'timestamp' is not null or undefined
            if (timestamp === null || timestamp === undefined) {
                throw new RequiredError('timestamp','Required parameter timestamp was null or undefined when calling onpointsOnpointIdHoursTimestampGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling onpointsOnpointIdHoursTimestampGet.');
            }
            const localVarPath = `/onpoints/{onpointId}/hours/{timestamp}`
                .replace(`{${"onpointId"}}`, encodeURIComponent(String(onpointId)))
                .replace(`{${"timestamp"}}`, encodeURIComponent(String(timestamp)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a contiguous range of hourly climatological weather data for an OnPoint™ point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly weather climatology for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdHoursTimestampStarttimestampEndGet(onpointId: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'onpointId' is not null or undefined
            if (onpointId === null || onpointId === undefined) {
                throw new RequiredError('onpointId','Required parameter onpointId was null or undefined when calling onpointsOnpointIdHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'timestampStart' is not null or undefined
            if (timestampStart === null || timestampStart === undefined) {
                throw new RequiredError('timestampStart','Required parameter timestampStart was null or undefined when calling onpointsOnpointIdHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'timestampEnd' is not null or undefined
            if (timestampEnd === null || timestampEnd === undefined) {
                throw new RequiredError('timestampEnd','Required parameter timestampEnd was null or undefined when calling onpointsOnpointIdHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling onpointsOnpointIdHoursTimestampStarttimestampEndGet.');
            }
            const localVarPath = `/onpoints/{onpointId}/hours/{timestampStart},{timestampEnd}`
                .replace(`{${"onpointId"}}`, encodeURIComponent(String(onpointId)))
                .replace(`{${"timestampStart"}}`, encodeURIComponent(String(timestampStart)))
                .replace(`{${"timestampEnd"}}`, encodeURIComponent(String(timestampEnd)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
    }
};

/**
 * OnpointsApi - functional programming interface
 * @export
 */
export const OnpointsApiFp = function(configuration?: Configuration) {
    return {
        /**
         * Returns a single day of climatological weather data for an OnPoint™ point.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of weather climatology for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdDaysDateGet(onpointId: number, date: string, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<ClimatologyOnpointDayObj> {
            const localVarFetchArgs = OnpointsApiFetchParamCreator(configuration).onpointsOnpointIdDaysDateGet(onpointId, date, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a contiguous range of daily climatological weather data for an OnPoint™ point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily weather climatology for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdDaysDateStartdateEndGet(onpointId: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<ClimatologyOnpointDayObj> {
            const localVarFetchArgs = OnpointsApiFetchParamCreator(configuration).onpointsOnpointIdDaysDateStartdateEndGet(onpointId, dateStart, dateEnd, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a single hour of climatological weather data for an OnPoint™ point.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of weather climatology for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdHoursTimestampGet(onpointId: number, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<ClimatologyOnpointHourObj> {
            const localVarFetchArgs = OnpointsApiFetchParamCreator(configuration).onpointsOnpointIdHoursTimestampGet(onpointId, timestamp, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a contiguous range of hourly climatological weather data for an OnPoint™ point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly weather climatology for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdHoursTimestampStarttimestampEndGet(onpointId: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<ClimatologyOnpointHourObj> {
            const localVarFetchArgs = OnpointsApiFetchParamCreator(configuration).onpointsOnpointIdHoursTimestampStarttimestampEndGet(onpointId, timestampStart, timestampEnd, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
    }
};

/**
 * OnpointsApi - factory interface
 * @export
 */
export const OnpointsApiFactory = function (configuration?: Configuration, fetch?: FetchAPI, basePath?: string) {
    return {
        /**
         * Returns a single day of climatological weather data for an OnPoint™ point.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of weather climatology for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdDaysDateGet(onpointId: number, date: string, fields: Array<string>, unitScale?: string, options?: any) {
            return OnpointsApiFp(configuration).onpointsOnpointIdDaysDateGet(onpointId, date, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a contiguous range of daily climatological weather data for an OnPoint™ point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily weather climatology for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdDaysDateStartdateEndGet(onpointId: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any) {
            return OnpointsApiFp(configuration).onpointsOnpointIdDaysDateStartdateEndGet(onpointId, dateStart, dateEnd, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a single hour of climatological weather data for an OnPoint™ point.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of weather climatology for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdHoursTimestampGet(onpointId: number, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any) {
            return OnpointsApiFp(configuration).onpointsOnpointIdHoursTimestampGet(onpointId, timestamp, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a contiguous range of hourly climatological weather data for an OnPoint™ point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly weather climatology for an OnPoint™ point.
         * @param {number} onpointId An OnPoint™ ID.
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        onpointsOnpointIdHoursTimestampStarttimestampEndGet(onpointId: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any) {
            return OnpointsApiFp(configuration).onpointsOnpointIdHoursTimestampStarttimestampEndGet(onpointId, timestampStart, timestampEnd, fields, unitScale, options)(fetch, basePath);
        },
    };
};

/**
 * OnpointsApi - object-oriented interface
 * @export
 * @class OnpointsApi
 * @extends {BaseAPI}
 */
export class OnpointsApi extends BaseAPI {
    /**
     * Returns a single day of climatological weather data for an OnPoint™ point.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A day of weather climatology for an OnPoint™ point.
     * @param {number} onpointId An OnPoint™ ID.
     * @param {string} date An date formatted as a RFC3339 date value.
     * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof OnpointsApi
     */
    public onpointsOnpointIdDaysDateGet(onpointId: number, date: string, fields: Array<string>, unitScale?: string, options?: any) {
        return OnpointsApiFp(this.configuration).onpointsOnpointIdDaysDateGet(onpointId, date, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a contiguous range of daily climatological weather data for an OnPoint™ point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A contiguous range of daily weather climatology for an OnPoint™ point.
     * @param {number} onpointId An OnPoint™ ID.
     * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
     * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
     * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof OnpointsApi
     */
    public onpointsOnpointIdDaysDateStartdateEndGet(onpointId: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any) {
        return OnpointsApiFp(this.configuration).onpointsOnpointIdDaysDateStartdateEndGet(onpointId, dateStart, dateEnd, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a single hour of climatological weather data for an OnPoint™ point.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary An hour of weather climatology for an OnPoint™ point.
     * @param {number} onpointId An OnPoint™ ID.
     * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
     * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof OnpointsApi
     */
    public onpointsOnpointIdHoursTimestampGet(onpointId: number, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any) {
        return OnpointsApiFp(this.configuration).onpointsOnpointIdHoursTimestampGet(onpointId, timestamp, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a contiguous range of hourly climatological weather data for an OnPoint™ point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A contiguous range of hourly weather climatology for an OnPoint™ point.
     * @param {number} onpointId An OnPoint™ ID.
     * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
     * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
     * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof OnpointsApi
     */
    public onpointsOnpointIdHoursTimestampStarttimestampEndGet(onpointId: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any) {
        return OnpointsApiFp(this.configuration).onpointsOnpointIdHoursTimestampStarttimestampEndGet(onpointId, timestampStart, timestampEnd, fields, unitScale, options)(this.fetch, this.basePath);
    }

}
/**
 * PointsApi - fetch parameter creator
 * @export
 */
export const PointsApiFetchParamCreator = function (configuration?: Configuration) {
    return {
        /**
         * Returns a single day of climatological weather data for a Latitude/Longitude point.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of weather climatology for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeDaysDateGet(latitude: number, longitude: number, date: string, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'latitude' is not null or undefined
            if (latitude === null || latitude === undefined) {
                throw new RequiredError('latitude','Required parameter latitude was null or undefined when calling pointsLatitudelongitudeDaysDateGet.');
            }
            // verify required parameter 'longitude' is not null or undefined
            if (longitude === null || longitude === undefined) {
                throw new RequiredError('longitude','Required parameter longitude was null or undefined when calling pointsLatitudelongitudeDaysDateGet.');
            }
            // verify required parameter 'date' is not null or undefined
            if (date === null || date === undefined) {
                throw new RequiredError('date','Required parameter date was null or undefined when calling pointsLatitudelongitudeDaysDateGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling pointsLatitudelongitudeDaysDateGet.');
            }
            const localVarPath = `/points/{latitude},{longitude}/days/{date}`
                .replace(`{${"latitude"}}`, encodeURIComponent(String(latitude)))
                .replace(`{${"longitude"}}`, encodeURIComponent(String(longitude)))
                .replace(`{${"date"}}`, encodeURIComponent(String(date)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a contiguous range of daily climatological weather data for a Latitude/Longitude point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily weather climatology for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeDaysDateStartdateEndGet(latitude: number, longitude: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'latitude' is not null or undefined
            if (latitude === null || latitude === undefined) {
                throw new RequiredError('latitude','Required parameter latitude was null or undefined when calling pointsLatitudelongitudeDaysDateStartdateEndGet.');
            }
            // verify required parameter 'longitude' is not null or undefined
            if (longitude === null || longitude === undefined) {
                throw new RequiredError('longitude','Required parameter longitude was null or undefined when calling pointsLatitudelongitudeDaysDateStartdateEndGet.');
            }
            // verify required parameter 'dateStart' is not null or undefined
            if (dateStart === null || dateStart === undefined) {
                throw new RequiredError('dateStart','Required parameter dateStart was null or undefined when calling pointsLatitudelongitudeDaysDateStartdateEndGet.');
            }
            // verify required parameter 'dateEnd' is not null or undefined
            if (dateEnd === null || dateEnd === undefined) {
                throw new RequiredError('dateEnd','Required parameter dateEnd was null or undefined when calling pointsLatitudelongitudeDaysDateStartdateEndGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling pointsLatitudelongitudeDaysDateStartdateEndGet.');
            }
            const localVarPath = `/points/{latitude},{longitude}/days/{dateStart},{dateEnd}`
                .replace(`{${"latitude"}}`, encodeURIComponent(String(latitude)))
                .replace(`{${"longitude"}}`, encodeURIComponent(String(longitude)))
                .replace(`{${"dateStart"}}`, encodeURIComponent(String(dateStart)))
                .replace(`{${"dateEnd"}}`, encodeURIComponent(String(dateEnd)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a single hour of climatological weather data for a Latitude/Longitude point.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of weather climatology for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeHoursTimestampGet(latitude: number, longitude: number, timestamp: Date, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'latitude' is not null or undefined
            if (latitude === null || latitude === undefined) {
                throw new RequiredError('latitude','Required parameter latitude was null or undefined when calling pointsLatitudelongitudeHoursTimestampGet.');
            }
            // verify required parameter 'longitude' is not null or undefined
            if (longitude === null || longitude === undefined) {
                throw new RequiredError('longitude','Required parameter longitude was null or undefined when calling pointsLatitudelongitudeHoursTimestampGet.');
            }
            // verify required parameter 'timestamp' is not null or undefined
            if (timestamp === null || timestamp === undefined) {
                throw new RequiredError('timestamp','Required parameter timestamp was null or undefined when calling pointsLatitudelongitudeHoursTimestampGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling pointsLatitudelongitudeHoursTimestampGet.');
            }
            const localVarPath = `/points/{latitude},{longitude}/hours/{timestamp}`
                .replace(`{${"latitude"}}`, encodeURIComponent(String(latitude)))
                .replace(`{${"longitude"}}`, encodeURIComponent(String(longitude)))
                .replace(`{${"timestamp"}}`, encodeURIComponent(String(timestamp)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a contiguous range of hourly climatological weather data for a Latitude/Longitude point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly weather climatology for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeHoursTimestampStarttimestampEndGet(latitude: number, longitude: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'latitude' is not null or undefined
            if (latitude === null || latitude === undefined) {
                throw new RequiredError('latitude','Required parameter latitude was null or undefined when calling pointsLatitudelongitudeHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'longitude' is not null or undefined
            if (longitude === null || longitude === undefined) {
                throw new RequiredError('longitude','Required parameter longitude was null or undefined when calling pointsLatitudelongitudeHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'timestampStart' is not null or undefined
            if (timestampStart === null || timestampStart === undefined) {
                throw new RequiredError('timestampStart','Required parameter timestampStart was null or undefined when calling pointsLatitudelongitudeHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'timestampEnd' is not null or undefined
            if (timestampEnd === null || timestampEnd === undefined) {
                throw new RequiredError('timestampEnd','Required parameter timestampEnd was null or undefined when calling pointsLatitudelongitudeHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling pointsLatitudelongitudeHoursTimestampStarttimestampEndGet.');
            }
            const localVarPath = `/points/{latitude},{longitude}/hours/{timestampStart},{timestampEnd}`
                .replace(`{${"latitude"}}`, encodeURIComponent(String(latitude)))
                .replace(`{${"longitude"}}`, encodeURIComponent(String(longitude)))
                .replace(`{${"timestampStart"}}`, encodeURIComponent(String(timestampStart)))
                .replace(`{${"timestampEnd"}}`, encodeURIComponent(String(timestampEnd)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
    }
};

/**
 * PointsApi - functional programming interface
 * @export
 */
export const PointsApiFp = function(configuration?: Configuration) {
    return {
        /**
         * Returns a single day of climatological weather data for a Latitude/Longitude point.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of weather climatology for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeDaysDateGet(latitude: number, longitude: number, date: string, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<ClimatologyPointDayObj> {
            const localVarFetchArgs = PointsApiFetchParamCreator(configuration).pointsLatitudelongitudeDaysDateGet(latitude, longitude, date, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a contiguous range of daily climatological weather data for a Latitude/Longitude point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily weather climatology for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeDaysDateStartdateEndGet(latitude: number, longitude: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<ClimatologyPointDayObj> {
            const localVarFetchArgs = PointsApiFetchParamCreator(configuration).pointsLatitudelongitudeDaysDateStartdateEndGet(latitude, longitude, dateStart, dateEnd, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a single hour of climatological weather data for a Latitude/Longitude point.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of weather climatology for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeHoursTimestampGet(latitude: number, longitude: number, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<ClimatologyPointHourObj> {
            const localVarFetchArgs = PointsApiFetchParamCreator(configuration).pointsLatitudelongitudeHoursTimestampGet(latitude, longitude, timestamp, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a contiguous range of hourly climatological weather data for a Latitude/Longitude point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly weather climatology for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeHoursTimestampStarttimestampEndGet(latitude: number, longitude: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<ClimatologyPointHourObj> {
            const localVarFetchArgs = PointsApiFetchParamCreator(configuration).pointsLatitudelongitudeHoursTimestampStarttimestampEndGet(latitude, longitude, timestampStart, timestampEnd, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
    }
};

/**
 * PointsApi - factory interface
 * @export
 */
export const PointsApiFactory = function (configuration?: Configuration, fetch?: FetchAPI, basePath?: string) {
    return {
        /**
         * Returns a single day of climatological weather data for a Latitude/Longitude point.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of weather climatology for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeDaysDateGet(latitude: number, longitude: number, date: string, fields: Array<string>, unitScale?: string, options?: any) {
            return PointsApiFp(configuration).pointsLatitudelongitudeDaysDateGet(latitude, longitude, date, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a contiguous range of daily climatological weather data for a Latitude/Longitude point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily weather climatology for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeDaysDateStartdateEndGet(latitude: number, longitude: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any) {
            return PointsApiFp(configuration).pointsLatitudelongitudeDaysDateStartdateEndGet(latitude, longitude, dateStart, dateEnd, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a single hour of climatological weather data for a Latitude/Longitude point.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of weather climatology for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeHoursTimestampGet(latitude: number, longitude: number, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any) {
            return PointsApiFp(configuration).pointsLatitudelongitudeHoursTimestampGet(latitude, longitude, timestamp, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a contiguous range of hourly climatological weather data for a Latitude/Longitude point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly weather climatology for a Latitude/Longitude point.
         * @param {number} latitude A latitude value between -90° and 90°.
         * @param {number} longitude A longitude value between -180° (West) and 180° (East).
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        pointsLatitudelongitudeHoursTimestampStarttimestampEndGet(latitude: number, longitude: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any) {
            return PointsApiFp(configuration).pointsLatitudelongitudeHoursTimestampStarttimestampEndGet(latitude, longitude, timestampStart, timestampEnd, fields, unitScale, options)(fetch, basePath);
        },
    };
};

/**
 * PointsApi - object-oriented interface
 * @export
 * @class PointsApi
 * @extends {BaseAPI}
 */
export class PointsApi extends BaseAPI {
    /**
     * Returns a single day of climatological weather data for a Latitude/Longitude point.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A day of weather climatology for a Latitude/Longitude point.
     * @param {number} latitude A latitude value between -90° and 90°.
     * @param {number} longitude A longitude value between -180° (West) and 180° (East).
     * @param {string} date An date formatted as a RFC3339 date value.
     * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof PointsApi
     */
    public pointsLatitudelongitudeDaysDateGet(latitude: number, longitude: number, date: string, fields: Array<string>, unitScale?: string, options?: any) {
        return PointsApiFp(this.configuration).pointsLatitudelongitudeDaysDateGet(latitude, longitude, date, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a contiguous range of daily climatological weather data for a Latitude/Longitude point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A contiguous range of daily weather climatology for a Latitude/Longitude point.
     * @param {number} latitude A latitude value between -90° and 90°.
     * @param {number} longitude A longitude value between -180° (West) and 180° (East).
     * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
     * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
     * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof PointsApi
     */
    public pointsLatitudelongitudeDaysDateStartdateEndGet(latitude: number, longitude: number, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any) {
        return PointsApiFp(this.configuration).pointsLatitudelongitudeDaysDateStartdateEndGet(latitude, longitude, dateStart, dateEnd, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a single hour of climatological weather data for a Latitude/Longitude point.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary An hour of weather climatology for a Latitude/Longitude point.
     * @param {number} latitude A latitude value between -90° and 90°.
     * @param {number} longitude A longitude value between -180° (West) and 180° (East).
     * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
     * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof PointsApi
     */
    public pointsLatitudelongitudeHoursTimestampGet(latitude: number, longitude: number, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any) {
        return PointsApiFp(this.configuration).pointsLatitudelongitudeHoursTimestampGet(latitude, longitude, timestamp, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a contiguous range of hourly climatological weather data for a Latitude/Longitude point. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A contiguous range of hourly weather climatology for a Latitude/Longitude point.
     * @param {number} latitude A latitude value between -90° and 90°.
     * @param {number} longitude A longitude value between -180° (West) and 180° (East).
     * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
     * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
     * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof PointsApi
     */
    public pointsLatitudelongitudeHoursTimestampStarttimestampEndGet(latitude: number, longitude: number, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any) {
        return PointsApiFp(this.configuration).pointsLatitudelongitudeHoursTimestampStarttimestampEndGet(latitude, longitude, timestampStart, timestampEnd, fields, unitScale, options)(this.fetch, this.basePath);
    }

}
/**
 * PostcodesApi - fetch parameter creator
 * @export
 */
export const PostcodesApiFetchParamCreator = function (configuration?: Configuration) {
    return {
        /**
         * Returns a single day of climatological weather data for a postcode.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of weather climatology for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeDaysDateGet(postcode: string, countryCode: string, date: string, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'postcode' is not null or undefined
            if (postcode === null || postcode === undefined) {
                throw new RequiredError('postcode','Required parameter postcode was null or undefined when calling postcodesPostcodecountryCodeDaysDateGet.');
            }
            // verify required parameter 'countryCode' is not null or undefined
            if (countryCode === null || countryCode === undefined) {
                throw new RequiredError('countryCode','Required parameter countryCode was null or undefined when calling postcodesPostcodecountryCodeDaysDateGet.');
            }
            // verify required parameter 'date' is not null or undefined
            if (date === null || date === undefined) {
                throw new RequiredError('date','Required parameter date was null or undefined when calling postcodesPostcodecountryCodeDaysDateGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling postcodesPostcodecountryCodeDaysDateGet.');
            }
            const localVarPath = `/postcodes/{postcode},{countryCode}/days/{date}`
                .replace(`{${"postcode"}}`, encodeURIComponent(String(postcode)))
                .replace(`{${"countryCode"}}`, encodeURIComponent(String(countryCode)))
                .replace(`{${"date"}}`, encodeURIComponent(String(date)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a contiguous range of daily climatological weather data for a postcode. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily weather climatology for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeDaysDateStartdateEndGet(postcode: string, countryCode: string, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'postcode' is not null or undefined
            if (postcode === null || postcode === undefined) {
                throw new RequiredError('postcode','Required parameter postcode was null or undefined when calling postcodesPostcodecountryCodeDaysDateStartdateEndGet.');
            }
            // verify required parameter 'countryCode' is not null or undefined
            if (countryCode === null || countryCode === undefined) {
                throw new RequiredError('countryCode','Required parameter countryCode was null or undefined when calling postcodesPostcodecountryCodeDaysDateStartdateEndGet.');
            }
            // verify required parameter 'dateStart' is not null or undefined
            if (dateStart === null || dateStart === undefined) {
                throw new RequiredError('dateStart','Required parameter dateStart was null or undefined when calling postcodesPostcodecountryCodeDaysDateStartdateEndGet.');
            }
            // verify required parameter 'dateEnd' is not null or undefined
            if (dateEnd === null || dateEnd === undefined) {
                throw new RequiredError('dateEnd','Required parameter dateEnd was null or undefined when calling postcodesPostcodecountryCodeDaysDateStartdateEndGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling postcodesPostcodecountryCodeDaysDateStartdateEndGet.');
            }
            const localVarPath = `/postcodes/{postcode},{countryCode}/days/{dateStart},{dateEnd}`
                .replace(`{${"postcode"}}`, encodeURIComponent(String(postcode)))
                .replace(`{${"countryCode"}}`, encodeURIComponent(String(countryCode)))
                .replace(`{${"dateStart"}}`, encodeURIComponent(String(dateStart)))
                .replace(`{${"dateEnd"}}`, encodeURIComponent(String(dateEnd)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a single hour of climatological weather data for a postcode.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of weather climatology for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeHoursTimestampGet(postcode: string, countryCode: string, timestamp: Date, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'postcode' is not null or undefined
            if (postcode === null || postcode === undefined) {
                throw new RequiredError('postcode','Required parameter postcode was null or undefined when calling postcodesPostcodecountryCodeHoursTimestampGet.');
            }
            // verify required parameter 'countryCode' is not null or undefined
            if (countryCode === null || countryCode === undefined) {
                throw new RequiredError('countryCode','Required parameter countryCode was null or undefined when calling postcodesPostcodecountryCodeHoursTimestampGet.');
            }
            // verify required parameter 'timestamp' is not null or undefined
            if (timestamp === null || timestamp === undefined) {
                throw new RequiredError('timestamp','Required parameter timestamp was null or undefined when calling postcodesPostcodecountryCodeHoursTimestampGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling postcodesPostcodecountryCodeHoursTimestampGet.');
            }
            const localVarPath = `/postcodes/{postcode},{countryCode}/hours/{timestamp}`
                .replace(`{${"postcode"}}`, encodeURIComponent(String(postcode)))
                .replace(`{${"countryCode"}}`, encodeURIComponent(String(countryCode)))
                .replace(`{${"timestamp"}}`, encodeURIComponent(String(timestamp)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
        /**
         * Returns a contiguous range of hourly climatological weather data for a postcode. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly weather climatology for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet(postcode: string, countryCode: string, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options: any = {}): FetchArgs {
            // verify required parameter 'postcode' is not null or undefined
            if (postcode === null || postcode === undefined) {
                throw new RequiredError('postcode','Required parameter postcode was null or undefined when calling postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'countryCode' is not null or undefined
            if (countryCode === null || countryCode === undefined) {
                throw new RequiredError('countryCode','Required parameter countryCode was null or undefined when calling postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'timestampStart' is not null or undefined
            if (timestampStart === null || timestampStart === undefined) {
                throw new RequiredError('timestampStart','Required parameter timestampStart was null or undefined when calling postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'timestampEnd' is not null or undefined
            if (timestampEnd === null || timestampEnd === undefined) {
                throw new RequiredError('timestampEnd','Required parameter timestampEnd was null or undefined when calling postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet.');
            }
            // verify required parameter 'fields' is not null or undefined
            if (fields === null || fields === undefined) {
                throw new RequiredError('fields','Required parameter fields was null or undefined when calling postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet.');
            }
            const localVarPath = `/postcodes/{postcode},{countryCode}/hours/{timestampStart},{timestampEnd}`
                .replace(`{${"postcode"}}`, encodeURIComponent(String(postcode)))
                .replace(`{${"countryCode"}}`, encodeURIComponent(String(countryCode)))
                .replace(`{${"timestampStart"}}`, encodeURIComponent(String(timestampStart)))
                .replace(`{${"timestampEnd"}}`, encodeURIComponent(String(timestampEnd)));
            const localVarUrlObj = url.parse(localVarPath, true);
            const localVarRequestOptions = Object.assign({ method: 'GET' }, options);
            const localVarHeaderParameter = {} as any;
            const localVarQueryParameter = {} as any;

            // authentication ApiKeyAuth required
            if (configuration && configuration.apiKey) {
                const localVarApiKeyValue = typeof configuration.apiKey === 'function'
					? configuration.apiKey("X-API-KEY")
					: configuration.apiKey;
                localVarHeaderParameter["X-API-KEY"] = localVarApiKeyValue;
            }

            if (fields) {
                localVarQueryParameter['fields'] = fields.join(COLLECTION_FORMATS["csv"]);
            }

            if (unitScale !== undefined) {
                localVarQueryParameter['unitScale'] = unitScale;
            }

            localVarUrlObj.query = Object.assign({}, localVarUrlObj.query, localVarQueryParameter, options.query);
            // fix override query string Detail: https://stackoverflow.com/a/7517673/1077943
            delete localVarUrlObj.search;
            localVarRequestOptions.headers = Object.assign({}, localVarHeaderParameter, options.headers);

            return {
                url: url.format(localVarUrlObj),
                options: localVarRequestOptions,
            };
        },
    }
};

/**
 * PostcodesApi - functional programming interface
 * @export
 */
export const PostcodesApiFp = function(configuration?: Configuration) {
    return {
        /**
         * Returns a single day of climatological weather data for a postcode.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of weather climatology for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeDaysDateGet(postcode: string, countryCode: string, date: string, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<ClimatologyPostcodeDayObj> {
            const localVarFetchArgs = PostcodesApiFetchParamCreator(configuration).postcodesPostcodecountryCodeDaysDateGet(postcode, countryCode, date, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a contiguous range of daily climatological weather data for a postcode. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily weather climatology for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeDaysDateStartdateEndGet(postcode: string, countryCode: string, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<ClimatologyPostcodeDayObj> {
            const localVarFetchArgs = PostcodesApiFetchParamCreator(configuration).postcodesPostcodecountryCodeDaysDateStartdateEndGet(postcode, countryCode, dateStart, dateEnd, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a single hour of climatological weather data for a postcode.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of weather climatology for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeHoursTimestampGet(postcode: string, countryCode: string, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<ClimatologyPostcodeHourObj> {
            const localVarFetchArgs = PostcodesApiFetchParamCreator(configuration).postcodesPostcodecountryCodeHoursTimestampGet(postcode, countryCode, timestamp, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
        /**
         * Returns a contiguous range of hourly climatological weather data for a postcode. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly weather climatology for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet(postcode: string, countryCode: string, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any): (fetch?: FetchAPI, basePath?: string) => Promise<ClimatologyPostcodeHourObj> {
            const localVarFetchArgs = PostcodesApiFetchParamCreator(configuration).postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet(postcode, countryCode, timestampStart, timestampEnd, fields, unitScale, options);
            return (fetch: FetchAPI = isomorphicFetch, basePath: string = BASE_PATH) => {
                return fetch(basePath + localVarFetchArgs.url, localVarFetchArgs.options).then((response) => {
                    if (response.status >= 200 && response.status < 300) {
                        return response.json();
                    } else {
                        throw response;
                    }
                });
            };
        },
    }
};

/**
 * PostcodesApi - factory interface
 * @export
 */
export const PostcodesApiFactory = function (configuration?: Configuration, fetch?: FetchAPI, basePath?: string) {
    return {
        /**
         * Returns a single day of climatological weather data for a postcode.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A day of weather climatology for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {string} date An date formatted as a RFC3339 date value.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeDaysDateGet(postcode: string, countryCode: string, date: string, fields: Array<string>, unitScale?: string, options?: any) {
            return PostcodesApiFp(configuration).postcodesPostcodecountryCodeDaysDateGet(postcode, countryCode, date, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a contiguous range of daily climatological weather data for a postcode. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of daily weather climatology for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
         * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
         * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeDaysDateStartdateEndGet(postcode: string, countryCode: string, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any) {
            return PostcodesApiFp(configuration).postcodesPostcodecountryCodeDaysDateStartdateEndGet(postcode, countryCode, dateStart, dateEnd, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a single hour of climatological weather data for a postcode.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary An hour of weather climatology for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeHoursTimestampGet(postcode: string, countryCode: string, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any) {
            return PostcodesApiFp(configuration).postcodesPostcodecountryCodeHoursTimestampGet(postcode, countryCode, timestamp, fields, unitScale, options)(fetch, basePath);
        },
        /**
         * Returns a contiguous range of hourly climatological weather data for a postcode. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
         * @summary A contiguous range of hourly weather climatology for a postcode.
         * @param {string} postcode A postcode string.
         * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
         * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
         * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
         * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
         * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
         * @param {*} [options] Override http request option.
         * @throws {RequiredError}
         */
        postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet(postcode: string, countryCode: string, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any) {
            return PostcodesApiFp(configuration).postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet(postcode, countryCode, timestampStart, timestampEnd, fields, unitScale, options)(fetch, basePath);
        },
    };
};

/**
 * PostcodesApi - object-oriented interface
 * @export
 * @class PostcodesApi
 * @extends {BaseAPI}
 */
export class PostcodesApi extends BaseAPI {
    /**
     * Returns a single day of climatological weather data for a postcode.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A day of weather climatology for a postcode.
     * @param {string} postcode A postcode string.
     * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
     * @param {string} date An date formatted as a RFC3339 date value.
     * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof PostcodesApi
     */
    public postcodesPostcodecountryCodeDaysDateGet(postcode: string, countryCode: string, date: string, fields: Array<string>, unitScale?: string, options?: any) {
        return PostcodesApiFp(this.configuration).postcodesPostcodecountryCodeDaysDateGet(postcode, countryCode, date, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a contiguous range of daily climatological weather data for a postcode. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A contiguous range of daily weather climatology for a postcode.
     * @param {string} postcode A postcode string.
     * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
     * @param {string} dateStart An date formatted as a RFC3339 date value that must occur temporally before dateEnd.
     * @param {string} dateEnd An date formatted as a RFC3339 date value that must occur temporally after dateStart.
     * @param {Array<string>} fields A comma separated list of field names to return. The date field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(precip, snowDepth, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof PostcodesApi
     */
    public postcodesPostcodecountryCodeDaysDateStartdateEndGet(postcode: string, countryCode: string, dateStart: string, dateEnd: string, fields: Array<string>, unitScale?: string, options?: any) {
        return PostcodesApiFp(this.configuration).postcodesPostcodecountryCodeDaysDateStartdateEndGet(postcode, countryCode, dateStart, dateEnd, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a single hour of climatological weather data for a postcode.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary An hour of weather climatology for a postcode.
     * @param {string} postcode A postcode string.
     * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
     * @param {Date} timestamp A timestamp formatted as an RFC3339 date-time value. The UTC offset is required.
     * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof PostcodesApi
     */
    public postcodesPostcodecountryCodeHoursTimestampGet(postcode: string, countryCode: string, timestamp: Date, fields: Array<string>, unitScale?: string, options?: any) {
        return PostcodesApiFp(this.configuration).postcodesPostcodecountryCodeHoursTimestampGet(postcode, countryCode, timestamp, fields, unitScale, options)(this.fetch, this.basePath);
    }

    /**
     * Returns a contiguous range of hourly climatological weather data for a postcode. The temporal range provided must not exceed 1 year in duration.  **IMPORTANT:** To authenticate to the Weather Source Climatology API, each request must contain your API key set to a custom header named `X-API-KEY`. If you do not have a Weather Source API key [sign up for a free 30-day developer account](https://developer.weathersourceapis.com/account/sign-up/). You may use the evaluation API Key `C0W60UOFRML47ytbXk4xlLBfv` to access example locations found in this documentation.  When using the \\\"Try it out\\\" capability in the documentation, the API key should be added by clicking the green \\\"Authorize\\\" button at the top of the page. 
     * @summary A contiguous range of hourly weather climatology for a postcode.
     * @param {string} postcode A postcode string.
     * @param {string} countryCode An uppercase 2-character [ISO 3166-1 Alpha-2 country code](https://developer.weathersourceapis.com/apis/countries-with-postal-code-support/).
     * @param {Date} timestampStart A timestamp formatted as an RFC3339 date-time value that must occur temporally before timestampEnd. The UTC offset is required.
     * @param {Date} timestampEnd A timestamp formatted as an RFC3339 date-time value that must occur temporally after timestampStart. The UTC offset is required.
     * @param {Array<string>} fields A comma separated list of field names to return. The timestamp field is always returned.  **Limiting the query to needed fields will improve the query response time.**  In addition to individual field names, following convenience field groups are also supported: * all *(all fields)* * allCldCvr *(derivatives of cldCvr)* * allHum *(derivatives of relHum, spcHum)* * allPrecip *(derivatives of precip, snowfall)* * allPres *(derivatives of mslPres, sfcPres)* * allRad *(derivatives of radSolar)* * allTemp *(derivatives of dewPt, feelsLike, temp, wetBulb)* * allWind *(derivatives of windDir, windDir80m, windDir100m, windSpd, windVecSpd, windVecSpd80m, windVecSpd100m)* * popular *(derivatives of cldCvr, feelsLike, precip, relHum, snowfall, temp, windDir, windSpd)* 
     * @param {string} [unitScale] The unit scale for returned values.&lt;br&gt;
     * @param {*} [options] Override http request option.
     * @throws {RequiredError}
     * @memberof PostcodesApi
     */
    public postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet(postcode: string, countryCode: string, timestampStart: Date, timestampEnd: Date, fields: Array<string>, unitScale?: string, options?: any) {
        return PostcodesApiFp(this.configuration).postcodesPostcodecountryCodeHoursTimestampStarttimestampEndGet(postcode, countryCode, timestampStart, timestampEnd, fields, unitScale, options)(this.fetch, this.basePath);
    }

}
